==> haskell-row-types-1.0.1.2-59.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-row-types.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 row-types
version:              1.0.1.2
visibility:           public
id:                   row-types-1.0.1.2-FuMsfCVBkwF72uFC405BUE
key:                  row-types-1.0.1.2-FuMsfCVBkwF72uFC405BUE
license:              MIT
maintainer:           dwincort@gmail.com
author:               Daniel Winograd-Cort, Matthew Farkas-Dyck
homepage:             https://github.com/target/row-types
synopsis:             Open Records and Variants
description:
    This package uses closed type families and type literals to implement open
    records and variants.
    The core is based off of the <https://hackage.haskell.org/package/CTRex CTRex>
    package, but it also includes polymorphic variants and a number of
    additional functions.  That said, it is not a proper superset of CTRex as it
    specifically forbids records from having more than one element of the same
    label.

category:             Data, Data Structures
abi:                  cbc40a57f61b4d3f3b592be654775051
exposed:              True
exposed-modules:
    Data.Row Data.Row.Dictionaries Data.Row.Internal Data.Row.Records
    Data.Row.Switch Data.Row.Variants

import-dirs:          /usr/lib/ghc-9.6.6/site-local/row-types-1.0.1.2
library-dirs:         /usr/lib/ghc-9.6.6/site-local/row-types-1.0.1.2
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/row-types-1.0.1.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-row-types
hs-libraries:         HSrow-types-1.0.1.2-FuMsfCVBkwF72uFC405BUE
depends:
    base-4.18.2.1 constraints-0.14.2-5Hasiz3qGyu5OkYwKIAmXY
    deepseq-1.4.8.1 generic-lens-2.2.2.0-6zNA6Lr1PDy3qgY1Y6mc8x
    hashable-1.4.7.0-DKTv0aQgcZmBEMi2BPTV4Z
    profunctors-5.6.3-1wSzWoPhCYk2rkrLUGeSHx text-2.0.2
    unordered-containers-0.2.20.1-50qrTxmoJy9AxZ7OdMnycu

haddock-interfaces:   /usr/share/doc/haskell-row-types/html/row-types.haddock
haddock-html:         /usr/share/doc/haskell-row-types/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-row-types-1.0.1.2-60-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-row-types.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 row-types
version:              1.0.1.2
visibility:           public
id:                   row-types-1.0.1.2-Lk5eej2rV6aHvk9G3xl6hA
key:                  row-types-1.0.1.2-Lk5eej2rV6aHvk9G3xl6hA
license:              MIT
maintainer:           dwincort@gmail.com
author:               Daniel Winograd-Cort, Matthew Farkas-Dyck
homepage:             https://github.com/target/row-types
synopsis:             Open Records and Variants
description:
    This package uses closed type families and type literals to implement open
    records and variants.
    The core is based off of the <https://hackage.haskell.org/package/CTRex CTRex>
    package, but it also includes polymorphic variants and a number of
    additional functions.  That said, it is not a proper superset of CTRex as it
    specifically forbids records from having more than one element of the same
    label.

category:             Data, Data Structures
abi:                  e379ba908de89dc5088900203f48692a
exposed:              True
exposed-modules:
    Data.Row Data.Row.Dictionaries Data.Row.Internal Data.Row.Records
    Data.Row.Switch Data.Row.Variants

import-dirs:          /usr/lib/ghc-9.6.6/site-local/row-types-1.0.1.2
library-dirs:         /usr/lib/ghc-9.6.6/site-local/row-types-1.0.1.2
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/row-types-1.0.1.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-row-types
hs-libraries:         HSrow-types-1.0.1.2-Lk5eej2rV6aHvk9G3xl6hA
depends:
    base-4.18.2.1 constraints-0.14.2-HITsp0guL9Z2vC96u1IEz
    deepseq-1.4.8.1 generic-lens-2.2.2.0-LsBaWquh2HB6u6ARwIVULv
    hashable-1.4.7.0-1GSULm1uRgQBgX6mu6tvYD
    profunctors-5.6.3-11ZlnmbI5xE8sDrL55YXrn text-2.0.2
    unordered-containers-0.2.20.1-L0jiELAFLwP1g4FZscm3B5

haddock-interfaces:   /usr/share/doc/haskell-row-types/html/row-types.haddock
haddock-html:         /usr/share/doc/haskell-row-types/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
